@@ -1,10 +1,13 @@
 """
 Please refer to the documentation provided in the README.md
 """
+from .base import *
 from .graphs import *
 from .models import *
 from .version import *
+from . import base
+from . import distances
 from . import graphs
 from . import models
 
-__all__ = graphs.__all__ + models.__all__
+__all__ = base.__all__ + graphs.__all__ + models.__all__ + ("distances",)
