@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
-from . import graphs
+from . import mincepy_types
 
 
 def get_mincepy_types():
     """The central entry point to provide historian type helpers"""
     types = list()
-    types.extend(graphs.HISTORIAN_TYPES)
+    types.extend(mincepy_types.HISTORIAN_TYPES)
 
     return types
